@@ -60,6 +60,8 @@ from .._impl import (
     scout_compute_api_CompactEnumPoint as CompactEnumPoint,
     scout_compute_api_ComputableNode as ComputableNode,
     scout_compute_api_ComputableNodeVisitor as ComputableNodeVisitor,
+    scout_compute_api_ComputeEventQuery as ComputeEventQuery,
+    scout_compute_api_ComputeEventQueryVisitor as ComputeEventQueryVisitor,
     scout_compute_api_ComputeNode as ComputeNode,
     scout_compute_api_ComputeNodeFromReferenceRequest as ComputeNodeFromReferenceRequest,
     scout_compute_api_ComputeNodeRequest as ComputeNodeRequest,
@@ -128,6 +130,10 @@ from .._impl import (
     scout_compute_api_ErrorCode as ErrorCode,
     scout_compute_api_ErrorResult as ErrorResult,
     scout_compute_api_ErrorType as ErrorType,
+    scout_compute_api_EventDispositionStatus as EventDispositionStatus,
+    scout_compute_api_EventTimeFilter as EventTimeFilter,
+    scout_compute_api_EventTimeFilterCondition as EventTimeFilterCondition,
+    scout_compute_api_EventType as EventType,
     scout_compute_api_EventsSearchRanges as EventsSearchRanges,
     scout_compute_api_ExcludeNegativeValues as ExcludeNegativeValues,
     scout_compute_api_ExponentialCurve as ExponentialCurve,
@@ -247,6 +253,7 @@ from .._impl import (
     scout_compute_api_PowerCurve as PowerCurve,
     scout_compute_api_PowerResultDetails as PowerResultDetails,
     scout_compute_api_ProductSeries as ProductSeries,
+    scout_compute_api_Property as Property,
     scout_compute_api_Range as Range,
     scout_compute_api_RangeAggregation as RangeAggregation,
     scout_compute_api_RangeAggregationOperation as RangeAggregationOperation,
@@ -274,6 +281,7 @@ from .._impl import (
     scout_compute_api_ScatterFitOptions as ScatterFitOptions,
     scout_compute_api_ScatterSummarizationStrategy as ScatterSummarizationStrategy,
     scout_compute_api_ScatterSummarizationStrategyVisitor as ScatterSummarizationStrategyVisitor,
+    scout_compute_api_SearchEventOriginType as SearchEventOriginType,
     scout_compute_api_SelectIndexFrom1dEnumArraySeries as SelectIndexFrom1dEnumArraySeries,
     scout_compute_api_SelectIndexFrom1dNumericArraySeries as SelectIndexFrom1dNumericArraySeries,
     scout_compute_api_SelectNewestPointsSeries as SelectNewestPointsSeries,
@@ -404,6 +412,8 @@ __all__ = [
     'CompactEnumPoint',
     'ComputableNode',
     'ComputableNodeVisitor',
+    'ComputeEventQuery',
+    'ComputeEventQueryVisitor',
     'ComputeNode',
     'ComputeNodeVisitor',
     'ComputeNodeFromReferenceRequest',
@@ -471,6 +481,10 @@ __all__ = [
     'ErrorCode',
     'ErrorResult',
     'ErrorType',
+    'EventDispositionStatus',
+    'EventTimeFilter',
+    'EventTimeFilterCondition',
+    'EventType',
     'EventsSearchRanges',
     'ExcludeNegativeValues',
     'ExponentialCurve',
@@ -590,6 +604,7 @@ __all__ = [
     'PowerCurve',
     'PowerResultDetails',
     'ProductSeries',
+    'Property',
     'Range',
     'RangeAggregation',
     'RangeAggregationOperation',
@@ -617,6 +632,7 @@ __all__ = [
     'ScatterFitOptions',
     'ScatterSummarizationStrategy',
     'ScatterSummarizationStrategyVisitor',
+    'SearchEventOriginType',
     'SelectIndexFrom1dEnumArraySeries',
     'SelectIndexFrom1dNumericArraySeries',
     'SelectNewestPointsSeries',
