@@ -18,5 +18,28 @@ from .._impl import (
     scout_notebook_api_SortByField as SortByField,
     scout_notebook_api_UpdateNotebookMetadataRequest as UpdateNotebookMetadataRequest,
     scout_notebook_api_UpdateNotebookRequest as UpdateNotebookRequest,
+    scout_notebook_api_UpdateRefNameRequest as UpdateRefNameRequest,
 )
 
+__all__ = [
+    'ChartWithOverlays',
+    'CreateNotebookRequest',
+    'GetAllLabelsAndPropertiesResponse',
+    'Lock',
+    'Notebook',
+    'NotebookDataScope',
+    'NotebookDataScopeVisitor',
+    'NotebookMetadata',
+    'NotebookMetadataWithRid',
+    'NotebookType',
+    'SearchNotebooksQuery',
+    'SearchNotebooksQueryVisitor',
+    'SearchNotebooksRequest',
+    'SearchNotebooksResponse',
+    'SortBy',
+    'SortByField',
+    'UpdateNotebookMetadataRequest',
+    'UpdateNotebookRequest',
+    'UpdateRefNameRequest',
+]
+
